"""
* Author: "PeppermintOS Team(peppermintosteam@proton.me)
*
* License: SPDX-License-Identifier: GPL-3.0-or-later
*
* Clean up the working folder and move ISO and other files
"""

import os
import shutil
from pathlib import Path
from datetime import date
import time

# Set the home path used regardless the user logged in
BSTRING_ISO_CONFIGS = '~/bubbles/iso_configs'
HOME_FOLDER = str(Path(BSTRING_ISO_CONFIGS).expanduser())
FUSATO_ROOT = '/fusato'


def make_check_sum():
    """ Generate the check sum files """
    os.chdir(HOME_FOLDER + FUSATO_ROOT)
    current_working_directory = os.getcwd().replace('/', '/')
    for root, dirs, files in os.walk(current_working_directory):
        for fiso in files:
            if fiso.endswith('.iso'):
                sha = "sha512sum "
                ext = "-sha512.checksum"
                gen_sum = sha + fiso + ' >' + fiso + ext
                os.system(gen_sum)


def copy_debian_xfce_based():
    """ Copy the new ISO debian baseto its Nightly folder
        XFCE
    """
    os.chdir(HOME_FOLDER + FUSATO_ROOT)
    current_working_directory = os.listdir(".")
    today = str(date.today())
    look_for_file_64 = Path('deb.64xfc')
    look_for_file_32 = Path('deb.32xfc')
    look_for_file_arm = Path('deb.armxfc')

    if look_for_file_64.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-Debian_64_xfce'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/deb64/xfce'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-Debian_64_xfce-sha512.checksum'
                des_sum = '/var/www/html/nightly/deb64/xfce'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)
    elif look_for_file_32.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-Debian_32_xfce'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/deb32/xfce'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-Debian_32_xfce-sha512.checksum'
                des_sum = '/var/www/html/nightly/deb32/xfce'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)
    elif look_for_file_arm.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-Debian_arm_xfce'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/debarm/xfce'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-Debian_arma_xfce-sha512.checksum'
                des_sum = '/var/www/html/nightly/debarm/xfce'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)


def copy_debian_gfb_based():
    """ Copy the new ISO debian base to its Nightly folder
        Gnome Flashback
    """
    os.chdir(HOME_FOLDER + FUSATO_ROOT)
    current_working_directory = os.listdir(".")
    today = str(date.today())
    look_for_file_64 = Path('deb.64gfb')
    look_for_file_32 = Path('deb.32gfb')
    look_for_file_arm = Path('deb.armgfb')

    if look_for_file_64.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-Debian_64_gfb'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/deb64/gnome-flashback'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-Debian_64_gfb-sha512.checksum'
                des_sum = '/var/www/html/nightly/deb64/gnome-flashback'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)
    elif look_for_file_32.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-Debian_32_gfb'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/deb32/gnome-flashback'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-Debian_32-sha512.checksum'
                des_sum = '/var/www/html/nightly/deb32/gnome-flashback'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)
    elif look_for_file_arm.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-Debian_arm_gfb'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/debarm/gnome-flashback'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-Debian_arm_gfb-sha512.checksum'
                des_sum = '/var/www/html/nightly/debarm/gnome-flashback'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)

def copy_debian_opb_based():
    """ Copy the new ISO debian base to its Nightly folder
        OpenBox
    """
    os.chdir(HOME_FOLDER + FUSATO_ROOT)
    current_working_directory = os.listdir(".")
    today = str(date.today())
    look_for_file_64 = Path('deb.64opb')
    look_for_file_32 = Path('deb.32opb')
    look_for_file_arm = Path('deb.armopb')

    if look_for_file_64.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-Debian_64_opb'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/deb64/openbox'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-Debian_64_opb-sha512.checksum'
                des_sum = '/var/www/html/nightly/deb64/openbox'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)
    elif look_for_file_32.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-Debian_32_opb'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/deb32/openbox'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-Debian_32_opb-sha512.checksum'
                des_sum = '/var/www/html/nightly/deb32/openbox'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)
    elif look_for_file_arm.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-Debian_arm_opb'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/debarm/openbox'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-Debian_arm_opb-sha512.checksum'
                des_sum = '/var/www/html/nightly/debarm/openbox'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)


def copy_devuan_xfce_based():
    """ Copy the new ISO devuan baseto its Nightly folder
        XFCE
    """
    os.chdir(HOME_FOLDER + FUSATO_ROOT)
    current_working_directory = os.listdir(".")
    today = str(date.today())
    look_for_file_64 = Path('dev.64xfc')
    look_for_file_32 = Path('dev.32xfc')
    look_for_file_arm = Path('dev.armxfc')

    if look_for_file_64.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-devuan_64_xfce'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/dev64/xfce'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-devuan_64_xfce-sha512.checksum'
                des_sum = '/var/www/html/nightly/dev64/xfce'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)
    elif look_for_file_32.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-devuan_32_xfce'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/dev32/xfce'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-devuan_32_xfce-sha512.checksum'
                des_sum = '/var/www/html/nightly/dev32/xfce'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)
    elif look_for_file_arm.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-devuan_arm_xfce'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/devarm/xfce'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-devuan_arma_xfce-sha512.checksum'
                des_sum = '/var/www/html/nightly/devarm/xfce'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)


def copy_devuan_gfb_based():
    """ Copy the new ISO devuan base to its Nightly folder
        Gnome Flashback
    """
    os.chdir(HOME_FOLDER + FUSATO_ROOT)
    current_working_directory = os.listdir(".")
    today = str(date.today())
    look_for_file_64 = Path('dev.64gfb')
    look_for_file_32 = Path('dev.32gfb')
    look_for_file_arm = Path('dev.armgfb')

    if look_for_file_64.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-devuan_64_gfb'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/dev64/gnome-flashback'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-devuan_64_gfb-sha512.checksum'
                des_sum = '/var/www/html/nightly/dev64/gnome-flashback'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)
    elif look_for_file_32.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-devuan_32_gfb'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/dev32/gnome-flashback'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-devuan_32-sha512.checksum'
                des_sum = '/var/www/html/nightly/dev32/gnome-flashback'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)
    elif look_for_file_arm.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-devuan_arm_gfb'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/devarm/gnome-flashback'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-devuan_arm_gfb-sha512.checksum'
                des_sum = '/var/www/html/nightly/devarm/gnome-flashback'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)

def copy_devuan_opb_based():
    """ Copy the new ISO devuan base to its Nightly folder
        OpenBox
    """
    os.chdir(HOME_FOLDER + FUSATO_ROOT)
    current_working_directory = os.listdir(".")
    today = str(date.today())
    look_for_file_64 = Path('dev.64opb')
    look_for_file_32 = Path('dev.32opb')
    look_for_file_arm = Path('dev.armopb')

    if look_for_file_64.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-devuan_64_opb'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/dev64/openbox'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-devuan_64_opb-sha512.checksum'
                des_sum = '/var/www/html/nightly/dev64/openbox'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)
    elif look_for_file_32.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-devuan_32_opb'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/dev32/openbox'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-devuan_32_opb-sha512.checksum'
                des_sum = '/var/www/html/nightly/dev32/openbox'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)
    elif look_for_file_arm.is_file():
        for f_v in current_working_directory:
            if f_v.endswith('.iso'):
                src_iso = f_v
                rdes = ('PeppermintOS-devuan_arm_opb'
                        + today +
                        '.iso'
                        )
                des_iso = '/var/www/html/nightly/devarm/openbox'
                os.rename(src_iso, rdes)
                shutil.copy(rdes, des_iso)
            if f_v.endswith('.checksum'):
                src_sum = f_v
                rdes_sum = 'PeppermintOS-devuan_arm_opb-sha512.checksum'
                des_sum = '/var/www/html/nightly/devarm/openbox'
                os.rename(src_sum, rdes_sum)
                shutil.copy(rdes_sum, des_sum)


def kill_old_iso():
    """ Delete older ISOs"""
    base_path = '/var/www/html/nightly/'
    arch_list = ['deb32/', 'deb64/', 'debarm/', 'dev32/', 'dev64/', 'devarm/']
    de_list = ['gnome-flashback', 'openbox', 'xfce']
    for archs in arch_list:
        for desktops in  de_list:
            full_path = []
            full_path.append(base_path + archs + desktops)
            for working_paths in full_path:
                N = 1
                os.chdir(os.path.join(os.getcwd(), working_paths))
                list_of_files = os.listdir()
                current_time = time.time()
                day = 86400
                for fls in list_of_files:
                    file_location = os.path.join(os.getcwd(), fls)
                    file_time = os.stat(file_location).st_mtime
                    if file_time < current_time - day*N:
                        print(f" Delete : {fls}")
                        os.remove(file_location)
